package com.vandyo.sentry.core.cases;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.vandyo.sentry.core.collectionMachine.CollectionMachine;
import com.vandyo.sentry.core.dto.ErrStatus;
import com.vandyo.sentry.core.dto.Res;
import com.vandyo.sentry.core.exceptions.CaseException;
import com.vandyo.sentry.core.tools.Signature;

import java.util.HashMap;
import java.util.Map;

/**
 * 获取消息接口
 */
public class MsgGetDecorator extends CaseDecorator {

    private static final String msgGetUrl = "/msg/msg_get";

    public MsgGetDecorator(Case aCase) {
        super(aCase);
    }

    @Override
    public Res<Map<String, String>> check() throws CaseException {
        Res<Map<String, String>> oldRes = super.check();
        if (oldRes.getSuccess()) {
            Map<String, String> data = new HashMap<>();
            data.put("uid", oldRes.getUId());
            data.put("size", String.valueOf(1));
            try {

                HttpResponse response = HttpRequest.get(Signature.msgHost + msgGetUrl + "?"
                        + Signature.getUrlParamsByMap(Signature.sign(data, oldRes.getSId())))
                        .execute();
                Res<Map<String, String>> newRes = new Res<>();
                newRes.setSId(oldRes.getSId());
                newRes.setUId(oldRes.getUId());

                if (response.isOk()) {
                    JSONObject json = JSONUtil.parseObj(response.body());
                    newRes.setSuccess(true);
                } else {
                    newRes.setKey(msgGetUrl);
                    newRes.setStatus(Signature.matchStatus(response.getStatus()));
                    newRes.setSuccess(false);
                }
                CollectionMachine.post(newRes);
                return newRes;
            }catch (Exception e){
                if (e.getMessage().toLowerCase().contains("timeout")){
                    throw new CaseException(msgGetUrl, ErrStatus.ErrTimeout);
                }else {
                    throw new CaseException(msgGetUrl,ErrStatus.ErrUnknown);
                }
            }
        } else {
            oldRes.setIgnore(true);
            return oldRes;
        }
    }
}
